#ifndef DEFINE_ISLIB_NORMAL_TERMINATION_HPP

#define DEFINE_ISLIB_NORMAL_TERMINATION_HPP

//
// Inclusion of standard header file
//
#include <exception>

namespace islib
  {
    //
    // Definition of class
    //
    class normal_termination:
      public std::exception
      {
      public:
        //
        // Definition of type
        //
        typedef normal_termination this_type;

        //
        // Declaration of constructor
        //
        explicit normal_termination ( int );

        //
        // Declaration of destructor
        //
        virtual ~normal_termination () throw ();

        //
        // Declaration of non-static member function
        //
        virtual int exit_status () const throw ();
        virtual char const *what () const throw ();

      private:
        //
        // Declaration of non-static data member
        //
        int member_exit_status;
      };
  }

#endif // DEFINE_ISLIB_NORMAL_TERMINATION_HPP

//
// End of file
//
